@@ -4,6 +4,10 @@
 from enum import Enum
 
 
+class InvalidTypeEnum(Enum):
+    INVALID = 0
+
+
 class TaskStateTypeEnum(Enum):
     INVALID = 0
     CANCELLED = 1
@@ -15,4 +19,6 @@ class TaskStateTypeEnum(Enum):
 class ErrorTypeEnum(Enum):
     UNKNOWN_ERROR = 0
     GENERAL_SQS_MESSAGE_ERROR = 1
-    GENERAL_DATA_ERROR = 2
\ No newline at end of file
+    GENERAL_DATA_ERROR = 2
+    FRAMEWORK_EXCEPTION = 3
+    INCORRECT_RESULT = 4
